// Copyright (c) ShapeTheCube (www.shapethecube.net) @ Atoru

namespace Eco.Mods.TechTree
{
    using System;
    using System.Collections.Generic;
    using System.ComponentModel;
    using Eco.Gameplay.Blocks;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.Components.Auth;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Economy;
    using Eco.Gameplay.Housing;
    using Eco.Gameplay.Interactions;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Minimap;
    using Eco.Gameplay.Objects;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Property;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Gameplay.Pipes.LiquidComponents;
    using Eco.Gameplay.Pipes.Gases;
    using Eco.Gameplay.Systems.Tooltip;
    using Eco.Shared;
    using Eco.Shared.Math;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.Shared.View;
    using Eco.Shared.Items;
    using Eco.Gameplay.Pipes;
    using Eco.World.Blocks;

    // level 1 Item Crate
    [Serialized]    
    [RequireComponent(typeof(AttachmentComponent))]
    [RequireComponent(typeof(PropertyAuthComponent))]
    [RequireComponent(typeof(MinimapComponent))]                
    [RequireComponent(typeof(LinkComponent))]                   
    public partial class BlockCrateAObject : WorldObject
    {
        public override string FriendlyName { get { return ItemCrateConfig.BLOCK_CRATE_NAME_A; } } 
        protected override void Initialize()
        {
            this.GetComponent<MinimapComponent>().Initialize("Storage");                                 
        }
        public override void Destroy()
        {
            base.Destroy();
        }
    }

    [Serialized]
    public partial class BlockCrateAItem : WorldObjectItem<BlockCrateAObject>
    {
        public override string FriendlyName { get { return ItemCrateConfig.BLOCK_CRATE_NAME_A; } } 
        public override string Description { get { return ItemCrateConfig.BLOCK_CRATE_INFO_A; } }

        static BlockCrateAItem()
        {
            
        }
        
    }

    [RequiresSkill(typeof(LumberWoodworkingSkill), 1)]
    public partial class BlockCrateARecipe : Recipe
    {
        public BlockCrateARecipe()
        {
            this.Products = new CraftingElement[]
            {
                new CraftingElement<BlockCrateAItem>(),
            };
            this.Ingredients = new CraftingElement[]
            {
                new CraftingElement<LogItem>(typeof(WoodworkingEfficiencySkill), 12, WoodworkingEfficiencySkill.MultiplicativeStrategy),
                new CraftingElement<HewnLogItem>(typeof(WoodworkingEfficiencySkill), 15, WoodworkingEfficiencySkill.MultiplicativeStrategy),
                new CraftingElement<WoodPulpItem>(typeof(BasicCraftingEfficiencySkill), 75, BasicCraftingEfficiencySkill.MultiplicativeStrategy),
            };
            SkillModifiedValue value = new SkillModifiedValue(2, LumberWoodworkingSkill.MultiplicativeStrategy, typeof(LumberWoodworkingSkill), "craft time");
            SkillModifiedValueManager.AddBenefitForObject(typeof(BlockCrateARecipe), Item.Get<BlockCrateAItem>().UILink(), value);
            SkillModifiedValueManager.AddSkillBenefit(Item.Get<BlockCrateAItem>().UILink(), value);
            this.CraftMinutes = value;
            this.Initialize(ItemCrateConfig.BLOCK_CRATE_NAME_A, typeof(BlockCrateARecipe));
            CraftingComponent.AddRecipe(typeof(WorkbenchObject), this);
        }
    }
    // level 2 Item Crate
    [Serialized]
    [RequireComponent(typeof(AttachmentComponent))]
    [RequireComponent(typeof(PropertyAuthComponent))]
    [RequireComponent(typeof(MinimapComponent))]
    [RequireComponent(typeof(LinkComponent))]
    public partial class BlockCrateBObject : WorldObject
    {
        public override string FriendlyName { get { return ItemCrateConfig.BLOCK_CRATE_NAME_B; } }
        protected override void Initialize()
        {
            this.GetComponent<MinimapComponent>().Initialize("Storage");
        }
        public override void Destroy()
        {
            base.Destroy();
        }
    }

    [Serialized]
    public partial class BlockCrateBItem : WorldObjectItem<BlockCrateBObject>
    {
        public override string FriendlyName { get { return ItemCrateConfig.BLOCK_CRATE_NAME_B; } }
        public override string Description { get { return ItemCrateConfig.BLOCK_CRATE_INFO_B; } }

        static BlockCrateBItem()
        {

        }

    }

    [RequiresSkill(typeof(LumberWoodworkingSkill), 2)]
    public partial class BlockCrateBRecipe : Recipe
    {
        public BlockCrateBRecipe()
        {
            this.Products = new CraftingElement[]
            {
                new CraftingElement<BlockCrateBItem>(),
            };
            this.Ingredients = new CraftingElement[]
            {
                new CraftingElement<HewnLogItem>(typeof(LumberWoodworkingEfficiencySkill), 21, LumberWoodworkingEfficiencySkill.MultiplicativeStrategy),
                new CraftingElement<BoardItem>(typeof(WoodworkingEfficiencySkill), 15, WoodworkingEfficiencySkill.MultiplicativeStrategy),
                new CraftingElement<WoodPulpItem>(typeof(BasicCraftingEfficiencySkill), 150, BasicCraftingEfficiencySkill.MultiplicativeStrategy),
            };
            SkillModifiedValue value = new SkillModifiedValue(2, LumberWoodworkingSkill.MultiplicativeStrategy, typeof(LumberWoodworkingSkill), "craft time");
            SkillModifiedValueManager.AddBenefitForObject(typeof(BlockCrateBRecipe), Item.Get<BlockCrateBItem>().UILink(), value);
            SkillModifiedValueManager.AddSkillBenefit(Item.Get<BlockCrateBItem>().UILink(), value);
            this.CraftMinutes = value;
            this.Initialize(ItemCrateConfig.BLOCK_CRATE_NAME_B, typeof(BlockCrateBRecipe));
            CraftingComponent.AddRecipe(typeof(CarpentryTableObject), this);
        }
    }
    // level 3 Item Crate
    [Serialized]
    [RequireComponent(typeof(AttachmentComponent))]
    [RequireComponent(typeof(PropertyAuthComponent))]
    [RequireComponent(typeof(MinimapComponent))]
    [RequireComponent(typeof(LinkComponent))]
    public partial class BlockCrateCObject : WorldObject
    {
        public override string FriendlyName { get { return ItemCrateConfig.BLOCK_CRATE_NAME_C; } }
        protected override void Initialize()
        {
            this.GetComponent<MinimapComponent>().Initialize("Storage");
        }
        public override void Destroy()
        {
            base.Destroy();
        }
    }

    [Serialized]
    public partial class BlockCrateCItem : WorldObjectItem<BlockCrateCObject>
    {
        public override string FriendlyName { get { return ItemCrateConfig.BLOCK_CRATE_NAME_C; } }
        public override string Description { get { return ItemCrateConfig.BLOCK_CRATE_INFO_C; } }

        static BlockCrateCItem()
        {

        }

    }

    [RequiresSkill(typeof(LumberWoodworkingSkill), 3)]
    public partial class BlockCrateCRecipe : Recipe
    {
        public BlockCrateCRecipe()
        {
            this.Products = new CraftingElement[]
            {
                new CraftingElement<BlockCrateCItem>(),
            };
            this.Ingredients = new CraftingElement[]
            {
                new CraftingElement<LumberItem>(typeof(LumberWoodworkingEfficiencySkill), 18, LumberWoodworkingEfficiencySkill.MultiplicativeStrategy),
                new CraftingElement<BoardItem>(typeof(LumberWoodworkingEfficiencySkill), 36, LumberWoodworkingEfficiencySkill.MultiplicativeStrategy),
                new CraftingElement<IronIngotItem>(typeof(LumberWoodworkingEfficiencySkill), 6, LumberWoodworkingEfficiencySkill.MultiplicativeStrategy),
            };
            SkillModifiedValue value = new SkillModifiedValue(2, LumberWoodworkingSkill.MultiplicativeStrategy, typeof(LumberWoodworkingSkill), "craft time");
            SkillModifiedValueManager.AddBenefitForObject(typeof(BlockCrateCRecipe), Item.Get<BlockCrateCItem>().UILink(), value);
            SkillModifiedValueManager.AddSkillBenefit(Item.Get<BlockCrateCItem>().UILink(), value);
            this.CraftMinutes = value;
            this.Initialize(ItemCrateConfig.BLOCK_CRATE_NAME_C, typeof(BlockCrateCRecipe));
            CraftingComponent.AddRecipe(typeof(SawmillObject), this);
        }
    }
}