// Copyright (c) ShapeTheCube (www.shapethecube.net) @ Atoru

namespace Eco.Mods.TechTree
{
    using System;
    using System.Collections.Generic;
    using System.ComponentModel;
    using Eco.Gameplay.Blocks;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.Components.Auth;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Economy;
    using Eco.Gameplay.Housing;
    using Eco.Gameplay.Interactions;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Minimap;
    using Eco.Gameplay.Objects;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Property;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Gameplay.Pipes.LiquidComponents;
    using Eco.Gameplay.Pipes.Gases;
    using Eco.Gameplay.Systems.Tooltip;
    using Eco.Shared;
    using Eco.Shared.Math;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.Shared.View;
    using Eco.Shared.Items;
    using Eco.Gameplay.Pipes;
    using Eco.World.Blocks;

    public static class ItemCrateConfig
    {
        // Item Crate: level 1
        public const Int32 ITEM_CRATE_SLOT_A = 52;            // amount of slot lines (13 slots per line)
        public const Int32 ITEM_CRATE_WEIGHT_A = 0;            // metric tons
        public static String ITEM_CRATE_TYPE_A = "items";       // mixed | items | carried
        public static String ITEM_CRATE_NAME_A = "Item Crate 1";  // block name
        public static String ITEM_CRATE_DESC_A = "<#5fafff>A crate you can store items in.</color>";   // block description
        public static String ITEM_CRATE_SLOTS_A = "<#c0c0c0>Slots:</color> <#ffffff>" + ITEM_CRATE_SLOT_A.ToString() + "</color>";
        public static String ITEM_CRATE_CARRY_A = "<#c0c0c0>Carry weight:</color> <#ffffff>" + (ITEM_CRATE_WEIGHT_A > 0 ? (ITEM_CRATE_WEIGHT_A * 1000).ToString() + "kg" : "unlimited") + "</color>";
        public static String ITEM_CRATE_INFO_A = ITEM_CRATE_DESC_A + "\n\n" + ITEM_CRATE_SLOTS_A + "\n" + ITEM_CRATE_CARRY_A;  // tooltip text
        // Item Crate: level 2
        public const Int32 ITEM_CRATE_SLOT_B = 78;            // amount of slot lines (13 slots per line)
        public const Int32 ITEM_CRATE_WEIGHT_B = 0;            // metric tons
        public static String ITEM_CRATE_TYPE_B = "items";       // mixed | items | carried
        public static String ITEM_CRATE_NAME_B = "Item Crate 2";  // block name
        public static String ITEM_CRATE_DESC_B = "<#5fafff>A crate you can store items in.</color>";   // block description
        public static String ITEM_CRATE_SLOTS_B = "<#c0c0c0>Slots:</color> <#ffffff>" + ITEM_CRATE_SLOT_B.ToString() + "</color>";
        public static String ITEM_CRATE_CARRY_B = "<#c0c0c0>Carry weight:</color> <#ffffff>" + (ITEM_CRATE_WEIGHT_B > 0 ? (ITEM_CRATE_WEIGHT_B * 1000).ToString() + "kg" : "unlimited") + "</color>";
        public static String ITEM_CRATE_INFO_B = ITEM_CRATE_DESC_B + "\n\n" + ITEM_CRATE_SLOTS_B + "\n" + ITEM_CRATE_CARRY_B;  // tooltip text
        // Item Crate: level 3
        public const Int32 ITEM_CRATE_SLOT_C = 130;            // amount of slot lines (13 slots per line)
        public const Int32 ITEM_CRATE_WEIGHT_C = 0;            // metric tons
        public static String ITEM_CRATE_TYPE_C = "items";       // mixed | items | carried
        public static String ITEM_CRATE_NAME_C = "Item Crate 3";  // block name
        public static String ITEM_CRATE_DESC_C = "<#5fafff>A crate you can store items in.</color>";   // block description
        public static String ITEM_CRATE_SLOTS_C = "<#c0c0c0>Slots:</color> <#ffffff>" + ITEM_CRATE_SLOT_C.ToString() + "</color>";
        public static String ITEM_CRATE_CARRY_C = "<#c0c0c0>Carry weight:</color> <#ffffff>" + (ITEM_CRATE_WEIGHT_C > 0 ? (ITEM_CRATE_WEIGHT_C * 1000).ToString() + "kg" : "unlimited") + "</color>";
        public static String ITEM_CRATE_INFO_C = ITEM_CRATE_DESC_C + "\n\n" + ITEM_CRATE_SLOTS_C + "\n" + ITEM_CRATE_CARRY_C;  // tooltip text
        // Block Crate: level 1
        public const Int32 BLOCK_CRATE_SLOT_A = 52;            // amount of slot lines (13 slots per line)
        public const Int32 BLOCK_CRATE_WEIGHT_A = 0;            // metric tons
        public static String BLOCK_CRATE_TYPE_A = "carried";       // mixed | items | carried
        public static String BLOCK_CRATE_NAME_A = "Block Crate 1";  // block name
        public static String BLOCK_CRATE_DESC_A = "<#5fafff>A crate you can store blocks in.</color>";   // block description
        public static String BLOCK_CRATE_SLOTS_A = "<#c0c0c0>Slots:</color> <#ffffff>" + BLOCK_CRATE_SLOT_A.ToString() + "</color>";
        public static String BLOCK_CRATE_CARRY_A = "<#c0c0c0>Carry weight:</color> <#ffffff>" + (BLOCK_CRATE_WEIGHT_A > 0 ? (BLOCK_CRATE_WEIGHT_A * 1000).ToString() + "kg" : "unlimited") + "</color>";
        public static String BLOCK_CRATE_INFO_A = BLOCK_CRATE_DESC_A + "\n\n" + BLOCK_CRATE_SLOTS_A + "\n" + BLOCK_CRATE_CARRY_A;  // tooltip text
        // Block Crate: level 2
        public const Int32 BLOCK_CRATE_SLOT_B = 78;            // amount of slot lines (13 slots per line)
        public const Int32 BLOCK_CRATE_WEIGHT_B = 0;            // metric tons
        public static String BLOCK_CRATE_TYPE_B = "carried";       // mixed | items | carried
        public static String BLOCK_CRATE_NAME_B = "Block Crate 2";  // block name
        public static String BLOCK_CRATE_DESC_B = "<#5fafff>A crate you can store blocks in.</color>";   // block description
        public static String BLOCK_CRATE_SLOTS_B = "<#c0c0c0>Slots:</color> <#ffffff>" + BLOCK_CRATE_SLOT_B.ToString() + "</color>";
        public static String BLOCK_CRATE_CARRY_B = "<#c0c0c0>Carry weight:</color> <#ffffff>" + (BLOCK_CRATE_WEIGHT_B > 0 ? (BLOCK_CRATE_WEIGHT_B * 1000).ToString() + "kg" : "unlimited") + "</color>";
        public static String BLOCK_CRATE_INFO_B = BLOCK_CRATE_DESC_B + "\n\n" + BLOCK_CRATE_SLOTS_B + "\n" + BLOCK_CRATE_CARRY_B;  // tooltip text
        // Block Crate: level 3
        public const Int32 BLOCK_CRATE_SLOT_C = 130;            // amount of slot lines (13 slots per line)
        public const Int32 BLOCK_CRATE_WEIGHT_C = 0;            // metric tons
        public static String BLOCK_CRATE_TYPE_C = "carried";       // mixed | items | carried
        public static String BLOCK_CRATE_NAME_C = "Block Crate 3";  // block name
        public static String BLOCK_CRATE_DESC_C = "<#5fafff>A crate you can store blocks in.</color>";   // block description
        public static String BLOCK_CRATE_SLOTS_C = "<#c0c0c0>Slots:</color> <#ffffff>" + BLOCK_CRATE_SLOT_C.ToString() + "</color>";
        public static String BLOCK_CRATE_CARRY_C = "<#c0c0c0>Carry weight:</color> <#ffffff>" + (BLOCK_CRATE_WEIGHT_C > 0 ? (BLOCK_CRATE_WEIGHT_C * 1000).ToString() + "kg" : "unlimited") + "</color>";
        public static String BLOCK_CRATE_INFO_C = BLOCK_CRATE_DESC_C + "\n\n" + BLOCK_CRATE_SLOTS_C + "\n" + BLOCK_CRATE_CARRY_C;  // tooltip text
        // Mixed Crate: level 1
        public const Int32 MIXED_CRATE_SLOT_A = 52;            // amount of slot lines (13 slots per line)
        public const Int32 MIXED_CRATE_WEIGHT_A = 10;            // metric tons
        public static String MIXED_CRATE_TYPE_A = "mixed";       // mixed | items | carried
        public static String MIXED_CRATE_NAME_A = "Universal Crate 1";  // block name
        public static String MIXED_CRATE_DESC_A = "<#5fafff>A crate you can store everything in.</color>";   // block description
        public static String MIXED_CRATE_SLOTS_A = "<#c0c0c0>Slots:</color> <#ffffff>" + MIXED_CRATE_SLOT_A.ToString() + "</color>";
        public static String MIXED_CRATE_CARRY_A = "<#c0c0c0>Carry weight:</color> <#ffffff>" + (MIXED_CRATE_WEIGHT_A > 0 ? (MIXED_CRATE_WEIGHT_A * 1000).ToString() + "kg" : "unlimited") + "</color>";
        public static String MIXED_CRATE_INFO_A = MIXED_CRATE_DESC_A + "\n\n" + MIXED_CRATE_SLOTS_A + "\n" + MIXED_CRATE_CARRY_A;  // tooltip text
        // Mixed Crate: level 2
        public const Int32 MIXED_CRATE_SLOT_B = 78;            // amount of slot lines (13 slots per line)
        public const Int32 MIXED_CRATE_WEIGHT_B = 25;            // metric tons
        public static String MIXED_CRATE_TYPE_B = "mixed";       // mixed | items | carried
        public static String MIXED_CRATE_NAME_B = "Universal Crate 2";  // block name
        public static String MIXED_CRATE_DESC_B = "<#5fafff>A crate you can store everything in.</color>";   // block description
        public static String MIXED_CRATE_SLOTS_B = "<#c0c0c0>Slots:</color> <#ffffff>" + MIXED_CRATE_SLOT_B.ToString() + "</color>";
        public static String MIXED_CRATE_CARRY_B = "<#c0c0c0>Carry weight:</color> <#ffffff>" + (MIXED_CRATE_WEIGHT_B > 0 ? (MIXED_CRATE_WEIGHT_B * 1000).ToString() + "kg" : "unlimited") + "</color>";
        public static String MIXED_CRATE_INFO_B = MIXED_CRATE_DESC_B + "\n\n" + MIXED_CRATE_SLOTS_B + "\n" + MIXED_CRATE_CARRY_B;  // tooltip text
        // Mixed Crate: level 3
        public const Int32 MIXED_CRATE_SLOT_C = 130;            // amount of slot lines (13 slots per line)
        public const Int32 MIXED_CRATE_WEIGHT_C = 40;            // metric tons
        public static String MIXED_CRATE_TYPE_C = "mixed";       // mixed | items | carried
        public static String MIXED_CRATE_NAME_C = "Universal Crate 3";  // block name
        public static String MIXED_CRATE_DESC_C = "<#5fafff>A crate you can store everything in.</color>";   // block description
        public static String MIXED_CRATE_SLOTS_C = "<#c0c0c0>Slots:</color> <#ffffff>" + MIXED_CRATE_SLOT_C.ToString() + "</color>";
        public static String MIXED_CRATE_CARRY_C = "<#c0c0c0>Carry weight:</color> <#ffffff>" + (MIXED_CRATE_WEIGHT_C > 0 ? (MIXED_CRATE_WEIGHT_C * 1000).ToString() + "kg" : "unlimited") + "</color>";
        public static String MIXED_CRATE_INFO_C = MIXED_CRATE_DESC_C + "\n\n" + MIXED_CRATE_SLOTS_C + "\n" + MIXED_CRATE_CARRY_C;  // tooltip text
    }
}